@@ -51,18 +51,24 @@ namespace Lum {
     AspectRatio();
     ~AspectRatio();
 
-    bool VisitChildren(Visitor &visitor, bool onlyVisible);
-
-    void SetAspectRatio(size_t hAspect, size_t vAspect);
-    void SetAlignment(HAlignment halign, VAlignment valign);
+    AspectRatio* SetAspectRatio(size_t hAspect, size_t vAspect);
+    AspectRatio* SetAlignment(HAlignment halign, VAlignment valign);
+    AspectRatio* SetObject(Object* object);
 
     Object* GetObject() const;
 
-    void SetObject(Object* object);
-
+    bool VisitChildren(Visitor &visitor, bool onlyVisible);
 
     void CalcSize();
     void Layout();
+
+    static AspectRatio* Create(Object* object,
+                               size_t hAspect, size_t vAspect,
+                               bool horizontalFlex=false, bool verticalFlex=false);
+    static AspectRatio* Create(Object* object,
+                               size_t hAspect, size_t vAspect,
+                               HAlignment halign, VAlignment valign,
+                               bool horizontalFlex=false, bool verticalFlex=false);
   };
 }
 
