@@ -58,11 +58,15 @@ namespace Lum {
         void PushUniqueFill(OS::DrawInfo* draw, size_t index, size_t maximum);
         void PopUniqueFill(OS::DrawInfo* draw, size_t index, size_t maximum);
 
+        bool IsLightTheme() const;
+
         size_t GetHorizontalFuelBarMinWidth() const;
         size_t GetHorizontalFuelBarMinHeight() const;
         size_t GetVerticalFuelBarMinWidth() const;
         size_t GetVerticalFuelBarMinHeight() const;
 
+        size_t GetCursorWidth(OS::Font* font) const;
+
         int GetSubMenuHorizontalOffset() const;
         bool OptimizeMenus() const;
         size_t MaxPopupMenuEntries() const;
