@@ -27,7 +27,7 @@ namespace Lum {
 
   DateView::DateView()
   {
-    SetBackground(OS::display->GetFill(OS::Display::boxedBackgroundFillIndex));
+    SetBackground(OS::display->GetFill(OS::Display::entryBackgroundFillIndex));
   }
 
   DateView::~DateView()
@@ -75,6 +75,11 @@ namespace Lum {
     Object::CalcSize();
   }
 
+  void DateView::PrepareForBackground(OS::DrawInfo* draw)
+  {
+    draw->disabled=true;
+  }
+
   void DateView::Draw(int x, int y, size_t w, size_t h)
   {
     Object::Draw(x,y,w,h);
