@@ -25,11 +25,28 @@ namespace Lum {
   namespace Model {
 
     Adjustment::Adjustment()
-    : top(new SizeT(1)),visible(new SizeT(0)),total(new SizeT(0)),stepSize(1)
+    : top(new SizeT(1)),
+      visible(new SizeT(0)),
+      total(new SizeT(0)),
+      stepSize(1)
     {
       // no code
     }
 
+    void Adjustment::On(bool notify)
+    {
+      top->On(notify);
+      visible->On(notify);
+      total->On(notify);
+    }
+
+    void Adjustment::Off()
+    {
+      top->Off();
+      visible->Off();
+      total->Off();
+    }
+
     /**
       As it is impossible to ensure that the relation between
       top, visible and total is not invalidated, this procedure
@@ -159,7 +176,7 @@ namespace Lum {
      */
     void Adjustment::SetTop(size_t top)
     {
-      if ((top>=1) && (top<=total->Get()-visible->Get()+1)) {
+      if (top>=1 && top<=total->Get()-visible->Get()+1) {
         if (this->top->IsNull() || this->top->Get()!=top) {
           this->top->Set(top);
           Notify();
@@ -218,6 +235,11 @@ namespace Lum {
     }
 
     void Adjustment::IncTop()
+    {
+      IncTop(stepSize);
+    }
+
+    void Adjustment::IncTop(size_t stepSize)
     {
       if (IsValid()) {
         if (top->Get()+stepSize-1<=total->Get()-visible->Get()) {
@@ -232,6 +254,11 @@ namespace Lum {
     }
 
     void Adjustment::DecTop()
+    {
+      DecTop(stepSize);
+    }
+
+    void Adjustment::DecTop(size_t stepSize)
     {
       if (IsValid()) {
         if (top->Get()>=1+stepSize) {
