@@ -149,7 +149,6 @@ namespace Lum {
 
       Window::Window(OS::Display* display)
       : display(dynamic_cast<Display*>(display)),
-        oldPress(0),lastPress(0),thisPress(0),
         balloonId(0),
         window(0),fullScreen(false),
         customWindowType(0),
@@ -158,6 +157,11 @@ namespace Lum {
         // no code
       }
 
+      Window::~Window()
+      {
+        // no code
+      }
+
       void Window::SetTitle(const std::wstring& name)
       {
         OS::Base::Window::SetTitle(name);
@@ -584,13 +588,6 @@ data        : POINTER TO ARRAY OF LONGINT;*/
           }
           return true;
         case ButtonPress:
-          oldButton=lastButton;
-          oldPress=lastPress;
-          lastButton=thisButton;
-          lastPress=thisPress;
-          thisButton=*dynamic_cast<MouseEvent*>(event);
-          thisPress=x11Event.xbutton.time;
-
           if (modalCount!=0) {
             return true;
           }
@@ -1031,6 +1028,8 @@ data        : POINTER TO ARRAY OF LONGINT;*/
 
       void Window::Close()
       {
+        display->RemoveWindow(this);
+
         if (IsOpen() && (window!=0)) {
           if (IsShown()) {
             if (grabMouse) {
@@ -1072,8 +1071,6 @@ data        : POINTER TO ARRAY OF LONGINT;*/
           window=0;
         }
 
-        display->RemoveWindow(this);
-
         OS::Base::Window::Close();
       }
 
@@ -1220,21 +1217,6 @@ data        : POINTER TO ARRAY OF LONGINT;*/
         return true;
       }
 
-      bool Window::IsDoubleClicked() const
-      {
-        return (thisPress-lastPress<=display->multiClickTime)
-          && (lastButton.type==thisButton.type)
-          && (lastButton.qualifier==thisButton.qualifier)
-          && (std::abs(lastButton.x-thisButton.x)<5)
-          && (std::abs(lastButton.y-thisButton.y)<5);
-      }
-
-      bool Window::IsTrippleClicked() const
-      {
-        return false;
-        //return (w.oldButton.type==w.lastButton.type) && (w.oldButton.qualifier==w.lastButton.qualifier) && (ABS(w.oldButton.x-w.lastButton.x)<5) && (ABS(w.oldButton.y-w.lastButton.y)<5) && (w.lastPress-w.oldPress<=D.display(Display).multiClickTime) && (w.lastButton.type==w.thisButton.type) && (w.lastButton.qualifier==w.thisButton.qualifier) && (ABS(w.lastButton.x-w.thisButton.x)<5) && (ABS(w.lastButton.y-w.thisButton.y)<5) && (w.thisPress-w.lastPress<=D.display(Display).multiClickTime);
-      }
-
       bool Window::SetFullScreen()
       {
         assert(window!=0);
