@@ -83,6 +83,17 @@ namespace Lum {
     return false;
   }
 
+  IMHandler::~IMHandler()
+  {
+    // no code
+  }
+
+  bool IMHandler::IsInEditingArea(OS::MouseEvent* event) const
+  {
+    return true;
+  }
+
+
   Object::Object()
   : parent(NULL),
     x(0),y(0),width(0),height(0),
@@ -498,6 +509,11 @@ namespace Lum {
     }
   }
 
+  bool Object::HasImplicitLabel() const
+  {
+    return false;
+  }
+
   void Object::SetWindow(OS::Window* window)
   {
     class SetWindowVisitor : public Visitor
@@ -753,6 +769,11 @@ namespace Lum {
     return requestsKeyboard;
   }
 
+  IMHandler* Object::GetIMHandler()
+  {
+    return NULL;
+  }
+
   class FocusFirstVisitor : public Visitor
   {
   public:
@@ -1996,6 +2017,18 @@ namespace Lum {
     return shortcutAlways;
   }
 
+  /**
+    If this method returns true, HandleMouseEvent() will be called before
+    HandleMouseEvent() for its child objects wil be called.
+
+    The default implementation returns false.
+
+    */
+  bool Object::InterceptMouseEvents() const
+  {
+    return false;
+  }
+
   /**
     Handles Mouse events.
 
@@ -2112,7 +2145,8 @@ namespace Lum {
       OS::display->KeyToKeyDescription(event.qualifier,name,desc);
       action=controller->GetActionForKey(desc);
 
-      if ((action!=Controller::actionNone) && controller->DoAction(this,action)) {
+      if (action!=Controller::actionNone &&
+          controller->DoAction(this,action)) {
         return true;
       }
     }
